pub enum Error {
ContextSettingsMissing,
IoPath {
path: PathBuf,
context: &'static str,
source: Error,
},
OpenpgpTechnology(Error),
YamlDeserialize {
context: String,
source: Error,
},
YamlSerialize {
context: &'static str,
source: Error,
},
Validation {
context: String,
source: Report,
},
VoaCore(Error),
}Expand description
The error that can occur when using VOA configuration files.
Variants
ContextSettingsMissing
There are no context settings.
IoPath
An I/O error occurred at a path.
Fields
OpenpgpTechnology(Error)
An OpenPGP technology error occurred.
YamlDeserialize
An error occurred while deserializing an object as a YAML string.
Fields

context: StringThe context in which the error occurred.
This is meant to complete the sentence “YAML deserialization error while “.

source: ErrorThe error source.
YamlSerialize
An error occurred while serializing an object as a YAML string.
Fields

context: &'static strThe context in which the error occurred.
This is meant to complete the sentence “YAML serialization error while “.

source: ErrorThe error source.
Validation
A garde validation error occurred.
Fields

context: StringThe context in which the error occurred.
This is meant to complete the sentence “Validation error while “.

source: ReportThe error source.
VoaCore(Error)
A voa_core::Error occurred.