ConfigTrustAnchorMode

Struct ConfigTrustAnchorMode 

pub struct ConfigTrustAnchorMode {
    required_certifications: Option<NumCertifications>,
    artifact_verifier_identity_domain_matches: Option<HashSet<DomainName>>,
    trust_anchor_fingerprint_matches: Option<HashSet<OpenpgpFingerprint>>,
}
Settings for the trust-anchor mode.

Note

This struct must be validated after creation.

Fields

required_certifications: Option<NumCertifications>

The number of certifications from a trust-anchor required to exist for an artifact verifier.

artifact_verifier_identity_domain_matches: Option<HashSet<DomainName>>

The identity of an artifact verifier must match one of the domains.

trust_anchor_fingerprint_matches: Option<HashSet<OpenpgpFingerprint>>

The fingerprint of an trust anchor must match one of the fingerprints.

Implementations

Source

impl ConfigTrustAnchorMode

pub fn new( required_certifications: Option<NumCertifications>, artifact_verifier_identity_domain_matches: Option<HashSet<DomainName>>, trust_anchor_fingerprint_matches: Option<HashSet<OpenpgpFingerprint>>, ) -> Result<Self, Error>

Creates a new ConfigTrustAnchorMode.

Errors

Returns an error if required_certifications is provided, but it is larger than the number of pinned trust anchor fingerprints in trust_anchor_fingerprint_matches.

pub fn required_certifications(&self) -> Option<NumCertifications>

Returns the optional NumCertifications.

pub fn artifact_verifier_identity_domain_matches( &self, ) -> Option<&HashSet<DomainName>>

Returns a reference to the optional set of artifact verifier DomainName entries.

pub fn trust_anchor_fingerprint_matches( &self, ) -> Option<&HashSet<OpenpgpFingerprint>>

Returns a reference to the optional set of trust anchor OpenpgpFingerprint entries.