TrustAnchorMode

Struct TrustAnchorMode 

pub struct TrustAnchorMode {
    required_certifications: NumCertifications,
    artifact_verifier_identity_domain_matches: HashSet<DomainName>,
    trust_anchor_fingerprint_matches: HashSet<OpenpgpFingerprint>,
}
Settings for the trust-anchor mode.

Fields

required_certifications: NumCertifications

The number of certifications from a trust-anchor required to exist for an artifact verifier.

artifact_verifier_identity_domain_matches: HashSet<DomainName>

The identity of an artifact verifier must match one of the domains.

trust_anchor_fingerprint_matches: HashSet<OpenpgpFingerprint>

The fingerprint of a trust anchor must match one of the fingerprints.

Implementations

Source

impl TrustAnchorMode

pub fn new( required_certifications: NumCertifications, artifact_verifier_identity_domain_matches: HashSet<DomainName>, trust_anchor_fingerprint_matches: HashSet<OpenpgpFingerprint>, ) -> Result<Self, Error>

Creates a new TrustAnchorMode.

Errors

Returns an error if required_certifications is larger than the length of trust_anchor_fingerprint_matches.

pub(crate) fn from_config_with_defaults( config: &ConfigTrustAnchorMode, defaults: &TrustAnchorMode, ) -> Result<Self, Error>

Creates a new TrustAnchorMode from a ConfigTrustAnchorMode and another TrustAnchorMode for defaults.

pub fn required_certifications(&self) -> NumCertifications

Returns the required number of certifications from a trust-anchor on an artifact verifier.

pub fn artifact_verifier_identity_domain_matches(&self) -> &HashSet<DomainName>

Returns a slice of the list of domains an artifact verifier must match at least one of.

pub fn trust_anchor_fingerprint_matches(&self) -> &HashSet<OpenpgpFingerprint>

Returns a slice of the list of fingerprints a trust-anchor must match at least one of.