TechnologySettings

Struct TechnologySettings 

pub struct TechnologySettings {
    pub(crate) origins: Vec<ConfigOrigin>,
    openpgp: OpenpgpSettings,
}
Settings for all supported cryptographic technologies.

Describes settings for all supported cryptographic technologies in a configuration object. May be used on a system, OS or context level.

Fields

origins: Vec<ConfigOrigin>openpgp: OpenpgpSettings

Implementations

Source

impl TechnologySettings

pub fn new(origins: Vec<ConfigOrigin>, openpgp: OpenpgpSettings) -> Self

Creates a new TechnologySettings from an OpenpgpSettings.

pub fn origins(&self) -> &[ConfigOrigin]

Returns a reference to the list of origins that were involved in the creation of the TechnologySettings.

pub(crate) fn from_config_with_defaults( config: &ConfigTechnologySettings, defaults: TechnologySettingsDefaults<'_>, ) -> Result<Self, Error>

Creates a new TechnologySettings from a ConfigTechnologySettings and defaults for any unset fields.

Errors

Returns an error, if a validated OpenpgpSettings cannot be created from the config and the set of defaults.

pub fn from_yaml_str(s: &str) -> Result<Self, Error>

Creates a new TechnologySettings from a YAML string.

pub fn openpgp_settings(&self) -> &OpenpgpSettings

Returns a reference to the tracked OpenpgpSettings.